@@ -59,6 +59,10 @@ Example:
                 await sub2.unsubscribe()
                 await events_asyncio.event_listener.async_stop()
 
+            await asyncio.sleep(1)
+            print("Renewing subscription..")
+            await sub.renew()
+
             await asyncio.sleep(100)
             await before_shutdown()
 
@@ -207,7 +211,7 @@ class EventListener(EventListenerBase):
             if not port:
                 return
             self.address = (ip_address, port)
-            self.session = ClientSession()
+            self.session = ClientSession(raise_for_status=True)
             self.is_running = True
             log.debug("Event Listener started")
 
@@ -272,11 +276,18 @@ class EventListener(EventListenerBase):
 
     async def async_stop(self):
         """Stop the listener."""
-        await self.site.stop()
-        await self.runner.cleanup()
-        await self.session.close()
-        self.sock.close()
-        self.sock = None
+        if self.site:
+            await self.site.stop()
+            self.site = None
+        if self.runner:
+            await self.runner.cleanup()
+            self.runner = None
+        if self.session:
+            await self.session.close()
+            self.session = None
+        if self.sock:
+            self.sock.close()
+            self.sock = None
         self.port = None
         self.ip_address = None
 
@@ -409,7 +420,7 @@ class Subscription(SubscriptionBase):
 
         """
         try:
-            return await self._wrap(super().renew, requested_timeout, is_autorenew)
+            return await super().renew(requested_timeout, is_autorenew)
         except Exception as exc:  # pylint: disable=broad-except
             msg = (
                 "An Exception occurred. Subscription to"
@@ -448,7 +459,10 @@ class Subscription(SubscriptionBase):
             `Subscription`: The Subscription instance.
         """
         try:
-            return await self._wrap(super().unsubscribe)
+            unsub = super().unsubscribe()
+            if unsub is None:
+                return
+            await unsub
         except Exception as exc:  # pylint: disable=broad-except
             if strict:
                 raise
@@ -495,20 +509,6 @@ class Subscription(SubscriptionBase):
 
         return _async_make_request()
 
-    async def _wrap(self, method, *args):
-
-        """Wrap a call into an awaitable."""
-        future = asyncio.Future()
-
-        def _wrap_action():
-            try:
-                future.set_result(method(*args))
-            except Exception as ex:  # pylint: disable=broad-except
-                future.set_exception(ex)
-
-        asyncio.get_running_loop().call_soon(_wrap_action)
-        return await future
-
 
 class SubscriptionsMapAio(SubscriptionsMap):
     """Maintains a mapping of sids to `soco.events_asyncio.Subscription`
